==> jc-1.4.0.tar.gz: soot/toolkits/graph/ArrayRefBlockGraph.h <==
// public class soot.toolkits.graph.ArrayRefBlockGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 91a4434dfc833013 soot_toolkits_graph_ArrayRefBlockGraph
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph

// header file dependencies
// @dep_header soot_toolkits_graph_BlockGraph

#include "soot/toolkits/graph/BlockGraph.h"

#ifndef _JC_soot_toolkits_graph_ArrayRefBlockGraph_H_
#define _JC_soot_toolkits_graph_ArrayRefBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$refs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$refs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$object	_jc_soot_toolkits_graph_ArrayRefBlockGraph$object;

typedef const struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_ArrayRefBlockGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$object *, struct _jc_soot_Body$object *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_BlockGraph$vmethods	soot_toolkits_graph_BlockGraph;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods	soot_toolkits_graph_ArrayRefBlockGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$refs {
    _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs	soot_toolkits_graph_ArrayRefBlockGraph;
    _jc_soot_toolkits_graph_BlockGraph$sub_refs	soot_toolkits_graph_BlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_BlockGraph$sub_nonrefs	soot_toolkits_graph_BlockGraph;
    _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs	soot_toolkits_graph_ArrayRefBlockGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$object {
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype _jc_soot_toolkits_graph_ArrayRefBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_ArrayRefBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_ArrayRefBlockGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_ArrayRefBlockGraph_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/ArrayRefBlockGraph.h <==
// public class soot.toolkits.graph.ArrayRefBlockGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 91a4434dfc833013 soot_toolkits_graph_ArrayRefBlockGraph
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph

// header file dependencies
// @dep_header soot_toolkits_graph_BlockGraph

#include "soot/toolkits/graph/BlockGraph.h"

#ifndef _JC_soot_toolkits_graph_ArrayRefBlockGraph_H_
#define _JC_soot_toolkits_graph_ArrayRefBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$refs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$refs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs	_jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$object	_jc_soot_toolkits_graph_ArrayRefBlockGraph$object;

typedef const struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_ArrayRefBlockGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_BlockGraph$vmethods	soot_toolkits_graph_BlockGraph;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vmethods	soot_toolkits_graph_ArrayRefBlockGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$refs {
    _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_refs	soot_toolkits_graph_ArrayRefBlockGraph;
    _jc_soot_toolkits_graph_BlockGraph$sub_refs	soot_toolkits_graph_BlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_BlockGraph$sub_nonrefs	soot_toolkits_graph_BlockGraph;
    _jc_soot_toolkits_graph_ArrayRefBlockGraph$sub_nonrefs	soot_toolkits_graph_ArrayRefBlockGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_ArrayRefBlockGraph$object {
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_ArrayRefBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_ArrayRefBlockGraph$vtype _jc_soot_toolkits_graph_ArrayRefBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_ArrayRefBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_ArrayRefBlockGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_ArrayRefBlockGraph_H_ */
